@@ -26,6 +26,34 @@ class CkafkaClient(AbstractClient):
     _service = 'ckafka'
 
 
+    def BatchCreateAcl(self, request):
+        """批量添加ACL策略
+
+        :param request: Request instance for BatchCreateAcl.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.BatchCreateAclRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.BatchCreateAclResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("BatchCreateAcl", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.BatchCreateAclResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAcl(self, request):
         """添加 ACL 策略
 
@@ -250,6 +278,62 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteInstancePre(self, request):
+        """删除预付费实例
+
+        :param request: Request instance for DeleteInstancePre.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteInstancePreRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteInstancePreResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteInstancePre", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteInstancePreResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DeleteRouteTriggerTime(self, request):
+        """修改删除路由延迟触发时间
+
+        :param request: Request instance for DeleteRouteTriggerTime.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteTriggerTimeRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DeleteRouteTriggerTimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteRouteTriggerTime", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteRouteTriggerTimeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteTopic(self, request):
         """删除ckafka主题
 
@@ -783,6 +867,34 @@ class CkafkaClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTopicSyncReplica(self, request):
+        """获取Topic 副本详情信息
+
+        :param request: Request instance for DescribeTopicSyncReplica.
+        :type request: :class:`tencentcloud.ckafka.v20190819.models.DescribeTopicSyncReplicaRequest`
+        :rtype: :class:`tencentcloud.ckafka.v20190819.models.DescribeTopicSyncReplicaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTopicSyncReplica", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTopicSyncReplicaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUser(self, request):
         """查询用户信息
 
