@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -91,6 +91,62 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def AttachCcn(self, request):
+        """本接口 (AttachCcn) 用于建立与云联网的关联。
+
+        :param request: Request instance for AttachCcn.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.AttachCcnRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.AttachCcnResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AttachCcn", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AttachCcnResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def AttachDisks(self, request):
+        """本接口（AttachDisks）用于挂载一个或多个云硬盘。
+
+        :param request: Request instance for AttachDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.AttachDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.AttachDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AttachDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AttachDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateBlueprint(self, request):
         """本接口 (CreateBlueprint) 用于创建镜像。
 
@@ -447,6 +503,174 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeCcnAttachedInstances(self, request):
+        """本接口 (DescribeCcnAttachedInstances) 用于查询云联网关联的实例信息。
+
+        :param request: Request instance for DescribeCcnAttachedInstances.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeCcnAttachedInstancesRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeCcnAttachedInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeCcnAttachedInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeCcnAttachedInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDiskConfigs(self, request):
+        """本接口（DescribeDiskConfigs）用于查询磁盘配置。
+
+        :param request: Request instance for DescribeDiskConfigs.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDiskConfigsRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDiskConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDiskConfigs", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDiskConfigsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDiskDiscount(self, request):
+        """本接口(DescribeDiskDiscount)用于查询云硬盘折扣信息。
+
+        :param request: Request instance for DescribeDiskDiscount.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDiskDiscountRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDiskDiscountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDiskDiscount", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDiskDiscountResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDisks(self, request):
+        """本接口（DescribeDisks）用于查询云硬盘信息。
+
+        :param request: Request instance for DescribeDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDisksDeniedActions(self, request):
+        """本接口（DescribeDisksDeniedActions）用于查询一个或多个云硬盘的操作限制列表信息。
+
+        :param request: Request instance for DescribeDisksDeniedActions.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksDeniedActionsRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksDeniedActionsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDisksDeniedActions", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDisksDeniedActionsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeDisksReturnable(self, request):
+        """本接口（DescribeDisksReturnable）用于查询云硬盘是否可退还。
+
+        :param request: Request instance for DescribeDisksReturnable.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksReturnableRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeDisksReturnableResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDisksReturnable", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDisksReturnableResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeFirewallRules(self, request):
         """本接口（DescribeFirewallRules）用于查询实例的防火墙规则。
 
@@ -653,6 +877,34 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeInstancesDiskNum(self, request):
+        """本接口(DescribeInstancesDiskNum)用于查询实例挂载云硬盘数量。
+
+        :param request: Request instance for DescribeInstancesDiskNum.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeInstancesDiskNumRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeInstancesDiskNumResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeInstancesDiskNum", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeInstancesDiskNumResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeInstancesReturnable(self, request):
         """本接口（DescribeInstancesReturnable）用于查询实例是否可退还。
 
@@ -905,6 +1157,62 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DetachCcn(self, request):
+        """本接口 (AttachCcn) 用于解除与云联网的关联。
+
+        :param request: Request instance for DetachCcn.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DetachCcnRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DetachCcnResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DetachCcn", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DetachCcnResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DetachDisks(self, request):
+        """本接口（DetachDisks）用于卸载一个或多个云硬盘。
+
+        :param request: Request instance for DetachDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DetachDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DetachDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DetachDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DetachDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DisassociateInstancesKeyPairs(self, request):
         """本接口（DisassociateInstancesKeyPairs）用于解除实例与指定密钥对的绑定关系。
 
@@ -995,6 +1303,34 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InquirePriceCreateDisks(self, request):
+        """本接口（InquirePriceCreateDisks）用于新购磁盘询价。
+
+        :param request: Request instance for InquirePriceCreateDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceCreateDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceCreateDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InquirePriceCreateDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InquirePriceCreateDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceCreateInstances(self, request):
         """本接口（InquiryPriceCreateInstances）用于创建实例询价。
 
@@ -1023,6 +1359,34 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def InquirePriceRenewDisks(self, request):
+        """本接口（InquirePriceRenewDisks）用于续费云硬盘询价。
+
+        :param request: Request instance for InquirePriceRenewDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceRenewDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceRenewDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("InquirePriceRenewDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.InquirePriceRenewDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def InquirePriceRenewInstances(self, request):
         """本接口（InquirePriceCreateInstances）用于续费实例询价。
 
@@ -1079,6 +1443,62 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyDisksAttribute(self, request):
+        """本接口(ModifyDisksAttribute)用于修改云硬盘属性。
+
+        :param request: Request instance for ModifyDisksAttribute.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.ModifyDisksAttributeRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.ModifyDisksAttributeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDisksAttribute", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDisksAttributeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyDisksRenewFlag(self, request):
+        """本接口（ModifyDisksRenewFlag）用于修改云硬盘续费标识。
+
+        :param request: Request instance for ModifyDisksRenewFlag.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.ModifyDisksRenewFlagRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.ModifyDisksRenewFlagResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyDisksRenewFlag", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyDisksRenewFlagResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyFirewallRuleDescription(self, request):
         """本接口（ModifyFirewallRuleDescription）用于修改单条防火墙规则描述。
 
@@ -1157,7 +1577,7 @@ class LighthouseClient(AbstractClient):
 
     def ModifyInstancesAttribute(self, request):
         """本接口（ModifyInstancesAttribute）用于修改实例的属性。
-        * “实例名称”仅为方便用户自己管理之用，腾讯云并不以此名称作为提交工单或是进行实例管理操作的依据。
+        * “实例名称”仅为方便用户自己管理之用。
         * 支持批量操作。每次请求批量实例的上限为 100。
         * 本接口为异步接口，请求发送成功后会返回一个 RequestId，此时操作并未立即完成。实例操作结果可以通过调用 DescribeInstances 接口查询，如果实例的最新操作状态（LatestOperationState）为“SUCCESS”，则代表操作成功。
 
@@ -1249,7 +1669,7 @@ class LighthouseClient(AbstractClient):
 
     def ModifySnapshotAttribute(self, request):
         """本接口（ModifySnapshotAttribute）用于修改指定快照的属性。
-        <li>“快照名称”仅为方便用户自己管理之用，腾讯云并不以此名称作为提交工单或是进行快照管理操作的依据。</li>
+        <li>“快照名称”仅为方便用户自己管理之用。</li>
 
         :param request: Request instance for ModifySnapshotAttribute.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.ModifySnapshotAttributeRequest`
@@ -1309,6 +1729,34 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ResetAttachCcn(self, request):
+        """本接口 (ResetAttachCcn) 用于关联云联网实例申请过期时，重新申请关联操作。
+
+        :param request: Request instance for ResetAttachCcn.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.ResetAttachCcnRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.ResetAttachCcnResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ResetAttachCcn", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ResetAttachCcnResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ResetInstance(self, request):
         """本接口（ResetInstance）用于重装指定实例上的镜像。
 
@@ -1346,7 +1794,9 @@ class LighthouseClient(AbstractClient):
         """本接口（ResetInstancesPassword）用于将实例操作系统的密码重置为用户指定的密码。
         * 只修改管理员帐号的密码。实例的操作系统不同，管理员帐号也会不一样（Windows 为 Administrator，Ubuntu 为 ubuntu ，其它系统为 root）。
         * 支持批量操作。将多个实例操作系统的密码重置为相同的密码。每次请求批量实例的上限为 100。
+        * 建议对运行中的实例先手动关机，然后再进行密码重置。如实例处于运行中状态，本接口操作过程中会对实例进行关机操作，尝试正常关机失败后进行强制关机。
         * 本接口为异步接口，请求发送成功后会返回一个 RequestId，此时操作并未立即完成。实例操作结果可以通过调用 DescribeInstances 接口查询，如果实例的最新操作状态（LatestOperationState）为“SUCCESS”，则代表操作成功。
+        注意：强制关机的效果等同于关闭物理计算机的电源开关。强制关机可能会导致数据丢失或文件系统损坏。
 
         :param request: Request instance for ResetInstancesPassword.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.ResetInstancesPasswordRequest`
@@ -1438,8 +1888,36 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def TerminateDisks(self, request):
+        """本接口（TerminateDisks）用于销毁一个或多个云硬盘。
+
+        :param request: Request instance for TerminateDisks.
+        :type request: :class:`tencentcloud.lighthouse.v20200324.models.TerminateDisksRequest`
+        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.TerminateDisksResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("TerminateDisks", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.TerminateDisksResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def TerminateInstances(self, request):
-        """本接口 (TerminateInstances) 用于退还实例。
+        """本接口 (TerminateInstances) 用于销毁实例。
 
         * 处于 SHUTDOWN 状态的实例，可通过本接口销毁，且不可恢复。
         * 支持批量操作，每次请求批量实例的上限为100。
